from click import group

from .cli_commands.init.init import init

@group()
def cli():
    pass

cli.add_command(init)
# cli.add_command()
# cli.add_command()
# cli.add_command()
# cli.add_command()



if __name__ == "__main__":
    cli()



from click import command, echo, option
from json import dump
from .func.check_mongo_string import check_mongo_string

arguments = {
    'name': {
        'prompt': "Name of the Application: ",
        'help': "The name of the Application. It should be unique for every app "
    },
    'version': {
        'prompt': "Version of the Application: ",
        'help': "The version of the Application."
    },
    'mongodb_connection_string': {
        'prompt': "MongoDB Connection String: ",
        'help': "The MongoDB Connection String for a cloud cloud cluster."
    },
    
}
dgupdaterconf_json = {
    "app_name": "",
    "version": "",
    "mongodb_connection_string": "",
    "files": {}
}

@command()
@option("--name", "-n", required = True, prompt = arguments["name"]["prompt"], help = arguments["name"]["help"])
@option("--version", "-v", required = True, prompt = arguments["version"]["prompt"], help = arguments["version"]["help"])    
@option("--mongodbstr", "-m", callback = check_mongo_string, required = True, prompt = arguments["mongodb_connection_string"]["prompt"], help = arguments["mongodb_connection_string"]["help"])
def init(name, version, mongodbstr):
    # print(name, version, mongodbstr)
    echo("\n\nInitializing this directory for autoupdation...")

    dgupdaterconf_json["app_name"] = name
    dgupdaterconf_json["version"] = version
    # dgupdaterconf_json["mongodb_connection_string"] = mongodbstr
    dgupdaterconf_json["mongodb_connection_string"] = mongodbstr




    with open("dgupdaterconf.json", "w") as f:
        dump(dgupdaterconf_json, f, indent = 4)
        




from setuptools import setup, find_packages
# print(find_packages())

setup(
    name="dgupdater",
    version="0.0.4",
    author="DarkGlance",
    author_email="darkglance.developer@gmail.com",
    description="A CLI based auto updation assistant tool for python applications",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    # url="https://github.com/Ashif4354/dgupdater",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.12",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Microsoft :: Windows",
    ],
    python_requires='>=3.6',
    install_requires=[
        "click>=7.0",
    ],
    entry_points={
        'console_scripts': [
            'dgupdater=dgupdater:cli',
        ],
    },
    project_urls = {
        'Github': "https://github.com/Ashif4354/dgupdater"
    }
)



from pymongo import MongoClient
from pymongo.errors import ConnectionFailure
from click import BadParameter

def check_mongo_string(ctx, param, value):
    # print(ctx, param, value)
    try:
        client = MongoClient(value, serverSelectionTimeoutMS = 1000)
        # print(client)
        client.admin.command('ping')
        # print(client.list_database_names())
        return value
    except ConnectionFailure as e:
       raise BadParameter("Enter a Valid MongoDB Connection String")
    

if __name__ == "__main__":
    print(check_mongo_string(1, 1, 'a'))